@@ -1,17 +1,17 @@
 /*
-  Copyright (c) 2005, 2006, 2007 Freetalk Core Team
+  Copyright (c) 2005-2014 Freetalk Core Team
   This file is part of Freetalk.
-  
+
   Freetalk is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published
   by the Free Software Foundation; either version 3 of the License,
   or (at your option) any later version.
-  
+
   Freetalk is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see
   <http://www.gnu.org/licenses/>.
@@ -20,7 +20,12 @@
 #ifndef __PRIMITIVES_H__
 #define __PRIMITIVES_H__
 
-#include <guile/gh.h>
+#ifndef _CONFIG_H
+#define _CONFIG_H
+#include "config.h"
+#endif
+
+#include <libguile.h>
 
 SCM ex_load (SCM scm_file);
 
@@ -48,7 +53,12 @@ SCM ex_set_password (SCM scm_password);
 SCM ex_get_sslconn (void);
 SCM ex_set_sslconn (SCM scm_ssl);
 
+SCM ex_get_tlsconn (void);
+SCM ex_set_tlsconn (SCM scm_ssl);
+
+
 SCM ex_connect (void);
+SCM ex_connect_blocking (void);
 SCM ex_disconnect (void);
 
 SCM ex_send_message (SCM scm_to, SCM scm_msg);
@@ -96,8 +106,6 @@ SCM ex_dict_remove (SCM scm_word);
 
 SCM ex_version (void);
 
-SCM ex_login_blocking (void);
-
 SCM ex_cli_on (void);
 
 SCM ex_main_loop (void);
@@ -115,13 +123,16 @@ SCM ex_give_repl (void);
 
 SCM ex_quit (SCM exit_code);
 
-SCM ex_send_file (SCM reciever, SCM file_name);
-SCM ex_set_allow_file (SCM cookie, SCM file_name);
-
 SCM ex_change_password (SCM newpass);
 
 SCM ex_roster_set_nickname (SCM jid, SCM nickname);
 
 SCM ex_bind_to_ctrl_key (SCM key, SCM command);
 
+SCM ex_run_command(SCM command);
+
+SCM ex_rl_redisplay();
+
+SCM ex_pager_display();
+
 #endif /* __PRIMITIVES_H__ */
