@@ -43,131 +43,6 @@
 #include "presence.h"
 #include "common.h"
 
-#ifdef FACEBOOK
-#include <curl/curl.h>
-#include <jansson.h>
-
-/* Practical limit */
-#define JSON_SIZE 512
-
-struct json_result {
-        char *data;
-        int pos;
-};
-
-static size_t
-json_response (void *ptr, size_t size, size_t nmemb, void *stream)
-{
-        struct json_result *json = (struct json_result *)stream;
-        size_t jsonlen = 0;
-        size_t new_pos = 0;
-
-        jsonlen = size * nmemb;
-        new_pos = json->pos + jsonlen;
-
-        if (new_pos >= (JSON_SIZE - 1)) {
-                PRINTF ("too large buffer");
-                return 0;
-        }
-
-        memcpy (json->data + json->pos, ptr, jsonlen);
-        json->pos += jsonlen;
-
-        return jsonlen;
-}
-
-static char *
-graph_request (const char *url)
-{
-        CURL *curl;
-        CURLM *curlm;
-        CURLMcode status;
-        char *json_data = NULL;
-        struct json_result json = {NULL, 0};
-
-        /* Thread un-safe but needed for initialization */
-        curl_global_init (CURL_GLOBAL_ALL);
-
-        curl = curl_easy_init ();
-        curlm = curl_multi_init ();
-        if (!curlm || !curl)
-                goto out;
-
-        json_data = g_malloc_n (1, JSON_SIZE);
-        if(!json_data)
-                goto out;
-
-        json.data = json_data;
-        json.pos = 0;
-
-        curl_multi_setopt (curlm, CURLMOPT_PIPELINING, 1);
-        curl_easy_setopt (curl, CURLOPT_URL, url);
-        curl_easy_setopt (curl, CURLOPT_WRITEFUNCTION, json_response);
-        curl_easy_setopt (curl, CURLOPT_WRITEDATA, &json);
-        curl_multi_add_handle (curlm, curl);
-
-        int still_running = 0;
-        do {
-                status = curl_multi_perform (curlm, &still_running);
-        } while (still_running);
-
-        if (status != 0) {
-                PRINTF ("%s", curl_multi_strerror (status));
-                goto out;
-        }
-
-        /* zero-terminate the result */
-        json.data [json.pos] = '\0';
-
-out:
-        curl_multi_remove_handle (curlm, curl);
-        curl_easy_cleanup (curl);
-        curl_multi_cleanup (curlm);
-        curl_global_cleanup ();
-        return json.data;
-
-}
-
-static char *
-get_username (uint64_t id)
-{
-        char url [256];
-        char *username = NULL;
-        char *text = NULL;
-
-        json_error_t error;
-        json_t *root = NULL;
-
-        snprintf (url, sizeof(url), "http://graph.facebook.com/%"SCNu64, id);
-        text = graph_request (url);
-        usleep (50000);
-        if (!text)
-                goto out;
-
-        root = json_loads (text, 0, &error);
-        if (!root) {
-                PRINTF ("error: on line %d: %s",
-                        error.line,
-                        error.text);
-                goto out;
-        }
-
-        json_unpack (root, "{s:s}", "username", &username);
-out:
-        if (text)
-                g_free (text);
-        return username;
-}
-
-#else
-
-static char *
-get_username (uint64_t id)
-{
-        return NULL;
-}
-
-#endif /* FACEBOOK */
 
 GSList *
 ft_roster_get (void)
@@ -283,50 +158,11 @@ ft_roster_lookup (const char *jid)
         return elem ? (FtRosterItem *)elem->data : NULL;
 }
 
-int
-get_username_id_from_jid (const gchar *jid, char **username, int64_t *id)
-{
-        char    *ptr           = NULL;
-        char    *token         = NULL;
-        int     ret            = -1;
-        char    jid_buf[256]   = {0,};
-        const char delimiter[] = "@";
-
-        ptr = g_strdup (jid);
-        if (!ptr)
-                return ret;
-
-        token = strsep (&ptr, delimiter);
-        if (token == NULL)
-                return ret;
-
-        *id = strtoll (token, (char **) NULL, 10);
-
-        if (*id == 0)
-                return ret;
-
-        char *real_jid = get_username (llabs (*id));
-
-        if (real_jid)
-                snprintf (jid_buf, sizeof(jid_buf), "%s@chat.facebook.com",
-                          real_jid);
-        else
-                snprintf (jid_buf, sizeof(jid_buf),
-                          "%"PRId64"@chat.facebook.com", *id);
-
-        *username = g_strdup (jid_buf);
-
-        ret = 0;
-        return ret;
-}
-
 static void
 roster_result_rcvd (LmMessage *msg)
 {
         LmMessageNode *query = lm_message_node_get_child (msg->node, "query");
         LmMessageNode *item = lm_message_node_get_child (query, "item");
-        char *username = NULL;
-        int64_t id     = 0;
 
         ft_presence_send_initial ();
 
@@ -338,21 +174,9 @@ roster_result_rcvd (LmMessage *msg)
                         PRINTF (_("error\n"));
                         return;
                 }
-                if (is_facebook ()) {
-                        if (get_username_id_from_jid
-                            (lm_message_node_get_attribute
-                             (item, "jid"), &username, &id)) {
-                                PRINTF (_("error\n"));
-                                return;
-                        }
 
-                        if (id)
-                                r_item->id = id;
-                        if (username)
-                                r_item->jid = username;
-                } else
-                        r_item->jid = g_strdup (lm_message_node_get_attribute
-                                                (item, "jid"));
+                r_item->jid = g_strdup (lm_message_node_get_attribute
+                                        (item, "jid"));
 
                 r_item->subscription = subscription_state (item);
                 r_item->nickname = g_strdup (lm_message_node_get_attribute
@@ -368,10 +192,6 @@ roster_result_rcvd (LmMessage *msg)
         }
 }
 
-/*
-  TODO: support facebook id->username, facebook doesn't send back "set" request
-*/
-
 static void
 roster_set_rcvd (LmMessage *msg)
 {
